@@ -1713,6 +1713,8 @@ class Update(MethodsInterface):
         return True
     
     def set_migration_host(self):
+        #TODO translate
+        self.startTask(_("Setting up migration host"))
         retval = []
         dv = self.clVars
         last_ts = dv.Get('cl_update_last_timestamp')
@@ -1824,10 +1826,13 @@ class Update(MethodsInterface):
         return True
 
     def update_increment_current_level(self):
+        #TODO add translation
+        self.startTask(_("Increasing update level"))
         current_level = int(self.clVars.Get('cl_update_level'))
         self.clVars.Write('cl_update_level', 
                 str(current_level + 1), location="system")
         self.clVars.Set("update.cl_update_use_migration_host",
                 Variable.Off)
         self.delete_binhost()
+        self.endTask()
         return True
\ No newline at end of file
