@@ -1858,6 +1858,7 @@ class VariableClUpdateLevel(Variable):
     Используется для выбора зеркала
     """
     type = "int"
+    value = "0"
 
 class VariableClUpdateUseMigrationHost(Variable):
     """
@@ -1870,6 +1871,7 @@ class VariableClCheckUpdateLevel(Variable):
     """
     Проверять уровень обновления 
     при соединении с binhost
+    NOT IMPLEMENTED  YET
     """
     type = "bool"
     value = "on"
\ No newline at end of file
